@@ -20,17 +20,6 @@ function Object:extend()
 end
 
 
-function Object:implement(...)
-  for _, cls in pairs({...}) do
-    for k, v in pairs(cls) do
-      if self[k] == nil and type(v) == "function" then
-        self[k] = v
-      end
-    end
-  end
-end
-
-
 function Object:is(T)
   local mt = getmetatable(self)
   while mt do
